@@ -11,6 +11,7 @@ from ikea_api._endpoints.item_pip import PipItem
 from ikea_api._endpoints.order_capture import OrderCapture
 from ikea_api._endpoints.purchases import Purchases
 from ikea_api._endpoints.search import Search, SearchType
+from ikea_api._endpoints.stock_ingka import IngkaStock
 from ikea_api._utils import format_item_code, parse_item_codes
 
 __all__ = [
@@ -20,6 +21,7 @@ __all__ = [
     "PipItem",
     "format_item_code",
     "parse_item_codes",
+    "IngkaStock",
 ]
 
 
